@@ -5,7 +5,7 @@ from django.views.generic import ListView
 from django.contrib import admin
 admin.autodiscover()
 
-from polls.views import ResultsView, PollView, PollVoteView, PollListView
+from polls.views import ResultsView, PollView, PollVoteView, PollListView, PollDeleteView
 from polls.forms import PollForm, PollVoteForm
 from polls.models import Poll
 
@@ -19,5 +19,7 @@ urlpatterns = patterns('',
                        url(r'^results/(?P<pk>\d+)$',
                            ResultsView.as_view(), name='poll_results'),
                        url(r'^$', PollListView.as_view(), name='polls'),
+                       url(r'^delete/(?P<pk>\d+)$',
+                           PollDeleteView.as_view(), name='poll_delete'),
                        url(r'^admin/', include(admin.site.urls)),
                        )
